.. testsetup:: *

   from pwnlib.elf import *
   from pwnlib.util.misc import which

:mod:`pwnlib.elf` --- ELF Executables and Libraries
===================================================

.. automodule:: pwnlib.elf


ELF Modules
-------------------

.. toctree::
    elf/elf
    elf/config
    elf/corefile
